aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2018-02-08 11:35:59 +0200
committerRoy Ben-Shabat <Roy@Twine-s.com>2018-02-08 11:35:59 +0200
commit781e923508aafa6d39c3d38f1b1d4664dedbb83d (patch)
treec3c70585633827808002b04b7ff669a09216a6e3 /Software/Visual_Studio
parent84a74bd9ea68a3f913e733a470ec64d1f8f50424 (diff)
downloadTango-781e923508aafa6d39c3d38f1b1d4664dedbb83d.tar.gz
Tango-781e923508aafa6d39c3d38f1b1d4664dedbb83d.zip
Modified IO Table To Graphs. Starting to IO's to separate components...
Diffstat (limited to 'Software/Visual_Studio')
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/IOVM.cs6
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs11
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MonitoringViewVM.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml.cs4
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/GRAPH.cs (renamed from Software/Visual_Studio/Tango.DAL.Remote/DB/IO.cs)3
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Context.cs2
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx111
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram92
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/Tango.DAL.Remote.csproj6
-rw-r--r--Software/Visual_Studio/Tango.Integration/Observables/Entities/Graph.cs (renamed from Software/Visual_Studio/Tango.Integration/Observables/Entities/Io.cs)46
-rw-r--r--Software/Visual_Studio/Tango.Integration/Observables/Enumerations/Graphs.cs181
-rw-r--r--Software/Visual_Studio/Tango.Integration/Observables/Enumerations/IOType.cs17
-rw-r--r--Software/Visual_Studio/Tango.Integration/Observables/ObservablesContext.cs16
-rw-r--r--Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapter.cs2
-rw-r--r--Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapterExtension.cs76
-rw-r--r--Software/Visual_Studio/Tango.Integration/Tango.Integration.csproj3
17 files changed, 359 insertions, 221 deletions
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/IOVM.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/IOVM.cs
index 83eee1333..e2a4fae0e 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/IOVM.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/IOVM.cs
@@ -10,8 +10,8 @@ namespace Tango.MachineStudio.Developer.ViewModels
{
public class IOVM : ExtendedObject
{
- private Io _io;
- public Io IO
+ private Graph _io;
+ public Graph IO
{
get { return _io; }
set { _io = value; RaisePropertyChangedAuto(); }
@@ -38,7 +38,7 @@ namespace Tango.MachineStudio.Developer.ViewModels
set { _value = value; RaisePropertyChanged(nameof(Value)); }
}
- public IOVM(Io io, String name)
+ public IOVM(Graph io, String name)
{
IO = io;
Name = name;
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs
index cf3cbab7d..e1166a9bc 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs
@@ -28,7 +28,6 @@ using Tango.Transport;
using Tango.Integration.Printing;
using Tango.Integration.Diagnostics;
using Microsoft.Win32;
-using Tango.Integration.Observables.Enumerations;
namespace Tango.MachineStudio.Developer.ViewModels
{
@@ -210,11 +209,11 @@ namespace Tango.MachineStudio.Developer.ViewModels
set { _isSideBarOpened = value; RaisePropertyChangedAuto(); }
}
- private ObservableCollection<Io> _availableGraphs;
+ private ObservableCollection<Graph> _availableGraphs;
/// <summary>
/// Gets or sets the available sensors.
/// </summary>
- public ObservableCollection<Io> AvailableGraphs
+ public ObservableCollection<Graph> AvailableGraphs
{
get { return _availableGraphs; }
set { _availableGraphs = value; RaisePropertyChangedAuto(); }
@@ -476,7 +475,7 @@ namespace Tango.MachineStudio.Developer.ViewModels
if (!this.DesignMode)
{
Adapter = ObservablesEntitiesAdapter.Instance;
- AvailableGraphs = Adapter.Ios.Where(x => (IOType)x.Type == IOType.Input || (IOType)x.Type == IOType.InputOutput).ToObservableCollection();
+ AvailableGraphs = Adapter.Graphs.ToObservableCollection();
}
Graphs = new ObservableCollection<IRealTimeGraph>();
@@ -1125,7 +1124,7 @@ namespace Tango.MachineStudio.Developer.ViewModels
/// Add sensor graph from available sensors to displayed graphs.
/// </summary>
/// <param name="sensor">The sensor.</param>
- public void OnDropAvailableGraph(Io sensor)
+ public void OnDropAvailableGraph(Graph sensor)
{
if (Graphs.Count < 8)
{
@@ -1209,7 +1208,7 @@ namespace Tango.MachineStudio.Developer.ViewModels
/// <param name="graph">The graph.</param>
public void RemoveGraph(IRealTimeGraph graph)
{
- var sensor = graph.Tag as Io;
+ var sensor = graph.Tag as Graph;
_controllers.Remove(sensor.Name);
graph.InnerGraph.Dispose();
Graphs.Remove(graph);
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MonitoringViewVM.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MonitoringViewVM.cs
index 8edbd7b83..a0cba6b6b 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MonitoringViewVM.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MonitoringViewVM.cs
@@ -47,7 +47,7 @@ namespace Tango.MachineStudio.Developer.ViewModels
if (!this.DesignMode)
{
Adapter = ObservablesEntitiesAdapter.Instance;
- AvailableControllers = Adapter.Ios.Select(x => new IOVM(x, x.Name)).ToObservableCollection();
+ AvailableControllers = Adapter.Graphs.Select(x => new IOVM(x, x.Name)).ToObservableCollection();
}
Controllers = new ObservableCollection<IOVM>();
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml
index 1ef6928f5..9f0927c63 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml
@@ -1796,7 +1796,7 @@
</ItemsPanelTemplate>
</ItemsControl.ItemsPanel>
<ItemsControl.ItemTemplate>
- <DataTemplate DataType="{x:Type observables:Io}">
+ <DataTemplate DataType="{x:Type observables:Graph}">
<Border dragAndDrop:DragAndDropService.Draggable="True" dragAndDrop:DragAndDropService.DraggingSurface="{Binding RelativeSource={RelativeSource AncestorType=UserControl},Path=DraggingSurface}" Margin="5" CornerRadius="3" Height="120" BorderThickness="1" BorderBrush="Silver" ClipToBounds="True">
<Border.Background>
<ImageBrush ImageSource="../Images/line_graph.png" Stretch="Fill"></ImageBrush>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml.cs
index e9111c86c..3922d80b2 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/MainView.xaml.cs
@@ -106,9 +106,9 @@ namespace Tango.MachineStudio.Developer.Views
private void OnDropAvailableGraph(object sender, DropEventArgs e)
{
- if (e.Draggable.DataContext is Io)
+ if (e.Draggable.DataContext is Graph)
{
- _vm.OnDropAvailableGraph(e.Draggable.DataContext as Io);
+ _vm.OnDropAvailableGraph(e.Draggable.DataContext as Graph);
}
}
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/IO.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/GRAPH.cs
index fff181051..ead2797c2 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/IO.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/GRAPH.cs
@@ -12,13 +12,12 @@ namespace Tango.DAL.Remote.DB
using System;
using System.Collections.Generic;
- public partial class IO
+ public partial class GRAPH
{
public int ID { get; set; }
public string GUID { get; set; }
public System.DateTime LAST_UPDATED { get; set; }
public int CODE { get; set; }
- public int TYPE { get; set; }
public string NAME { get; set; }
public string DESCRIPTION { get; set; }
public double MIN { get; set; }
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Context.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Context.cs
index 6db73ac0a..6dcb22ee4 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Context.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Context.cs
@@ -45,10 +45,10 @@ namespace Tango.DAL.Remote.DB
public virtual DbSet<EVENT_TYPES_ACTIONS> EVENT_TYPES_ACTIONS { get; set; }
public virtual DbSet<FIBER_SHAPES> FIBER_SHAPES { get; set; }
public virtual DbSet<FIBER_SYNTHS> FIBER_SYNTHS { get; set; }
+ public virtual DbSet<GRAPH> GRAPHS { get; set; }
public virtual DbSet<HARDWARE_VERSIONS> HARDWARE_VERSIONS { get; set; }
public virtual DbSet<IDS_PACK_FORMULAS> IDS_PACK_FORMULAS { get; set; }
public virtual DbSet<IDS_PACKS> IDS_PACKS { get; set; }
- public virtual DbSet<IO> IOS { get; set; }
public virtual DbSet<JOB_RUNS> JOB_RUNS { get; set; }
public virtual DbSet<JOB> JOBS { get; set; }
public virtual DbSet<LINEAR_MASS_DENSITY_UNITS> LINEAR_MASS_DENSITY_UNITS { get; set; }
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
index d692a0cc6..e107655cb 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
@@ -257,6 +257,23 @@
<Property Name="NAME" Type="nvarchar" MaxLength="50" Nullable="false" />
<Property Name="CODE" Type="int" Nullable="false" />
</EntityType>
+ <EntityType Name="GRAPHS">
+ <Key>
+ <PropertyRef Name="ID" />
+ </Key>
+ <Property Name="ID" Type="int" StoreGeneratedPattern="Identity" Nullable="false" />
+ <Property Name="GUID" Type="varchar" MaxLength="36" Nullable="false" />
+ <Property Name="LAST_UPDATED" Type="datetime2" Precision="3" Nullable="false" />
+ <Property Name="CODE" Type="int" Nullable="false" />
+ <Property Name="NAME" Type="varchar" MaxLength="100" Nullable="false" />
+ <Property Name="DESCRIPTION" Type="varchar" MaxLength="100" Nullable="false" />
+ <Property Name="MIN" Type="float" Nullable="false" />
+ <Property Name="MAX" Type="float" Nullable="false" />
+ <Property Name="UNITS" Type="nvarchar" MaxLength="50" Nullable="false" />
+ <Property Name="POINTS_PER_FRAME" Type="int" Nullable="false" />
+ <Property Name="MULTI_CHANNEL" Type="bit" Nullable="false" />
+ <Property Name="CHANNEL_COUNT" Type="int" Nullable="false" />
+ </EntityType>
<EntityType Name="HARDWARE_VERSIONS">
<Key>
<PropertyRef Name="GUID" />
@@ -295,24 +312,6 @@
<Property Name="PACK_INDEX" Type="int" Nullable="false" />
<Property Name="IDS_PACK_FORMULA_GUID" Type="varchar" MaxLength="36" Nullable="false" />
</EntityType>
- <EntityType Name="IOS">
- <Key>
- <PropertyRef Name="ID" />
- </Key>
- <Property Name="ID" Type="int" StoreGeneratedPattern="Identity" Nullable="false" />
- <Property Name="GUID" Type="varchar" MaxLength="36" Nullable="false" />
- <Property Name="LAST_UPDATED" Type="datetime2" Precision="3" Nullable="false" />
- <Property Name="CODE" Type="int" Nullable="false" />
- <Property Name="TYPE" Type="int" Nullable="false" />
- <Property Name="NAME" Type="varchar" MaxLength="100" Nullable="false" />
- <Property Name="DESCRIPTION" Type="varchar" MaxLength="100" Nullable="false" />
- <Property Name="MIN" Type="float" Nullable="false" />
- <Property Name="MAX" Type="float" Nullable="false" />
- <Property Name="UNITS" Type="nvarchar" MaxLength="50" Nullable="false" />
- <Property Name="POINTS_PER_FRAME" Type="int" Nullable="false" />
- <Property Name="MULTI_CHANNEL" Type="bit" Nullable="false" />
- <Property Name="CHANNEL_COUNT" Type="int" Nullable="false" />
- </EntityType>
<EntityType Name="JOB_RUNS">
<Key>
<PropertyRef Name="GUID" />
@@ -1336,10 +1335,10 @@
<EntitySet Name="EVENT_TYPES_ACTIONS" EntityType="Self.EVENT_TYPES_ACTIONS" Schema="dbo" store:Type="Tables" />
<EntitySet Name="FIBER_SHAPES" EntityType="Self.FIBER_SHAPES" Schema="dbo" store:Type="Tables" />
<EntitySet Name="FIBER_SYNTHS" EntityType="Self.FIBER_SYNTHS" Schema="dbo" store:Type="Tables" />
+ <EntitySet Name="GRAPHS" EntityType="Self.GRAPHS" Schema="dbo" store:Type="Tables" />
<EntitySet Name="HARDWARE_VERSIONS" EntityType="Self.HARDWARE_VERSIONS" Schema="dbo" store:Type="Tables" />
<EntitySet Name="IDS_PACK_FORMULAS" EntityType="Self.IDS_PACK_FORMULAS" Schema="dbo" store:Type="Tables" />
<EntitySet Name="IDS_PACKS" EntityType="Self.IDS_PACKS" Schema="dbo" store:Type="Tables" />
- <EntitySet Name="IOS" EntityType="Self.IOS" Schema="dbo" store:Type="Tables" />
<EntitySet Name="JOB_RUNS" EntityType="Self.JOB_RUNS" Schema="dbo" store:Type="Tables" />
<EntitySet Name="JOBS" EntityType="Self.JOBS" Schema="dbo" store:Type="Tables" />
<EntitySet Name="LINEAR_MASS_DENSITY_UNITS" EntityType="Self.LINEAR_MASS_DENSITY_UNITS" Schema="dbo" store:Type="Tables" />
@@ -1608,10 +1607,10 @@
<EntitySet Name="EVENT_TYPES_ACTIONS" EntityType="RemoteModel.EVENT_TYPES_ACTIONS" />
<EntitySet Name="FIBER_SHAPES" EntityType="RemoteModel.FIBER_SHAPES" />
<EntitySet Name="FIBER_SYNTHS" EntityType="RemoteModel.FIBER_SYNTHS" />
+ <EntitySet Name="GRAPHS" EntityType="RemoteModel.GRAPH" />
<EntitySet Name="HARDWARE_VERSIONS" EntityType="RemoteModel.HARDWARE_VERSIONS" />
<EntitySet Name="IDS_PACK_FORMULAS" EntityType="RemoteModel.IDS_PACK_FORMULAS" />
<EntitySet Name="IDS_PACKS" EntityType="RemoteModel.IDS_PACKS" />
- <EntitySet Name="IOS" EntityType="RemoteModel.IO" />
<EntitySet Name="JOB_RUNS" EntityType="RemoteModel.JOB_RUNS" />
<EntitySet Name="JOBS" EntityType="RemoteModel.JOB" />
<EntitySet Name="LINEAR_MASS_DENSITY_UNITS" EntityType="RemoteModel.LINEAR_MASS_DENSITY_UNITS" />
@@ -2143,6 +2142,23 @@
<Property Name="CODE" Type="Int32" Nullable="false" />
<NavigationProperty Name="RMLS" Relationship="RemoteModel.FK_RML_FIBER_SYNTHESIS" FromRole="FIBER_SYNTHS" ToRole="RML" />
</EntityType>
+ <EntityType Name="GRAPH">
+ <Key>
+ <PropertyRef Name="ID" />
+ </Key>
+ <Property Name="ID" Type="Int32" Nullable="false" annotation:StoreGeneratedPattern="Identity" />
+ <Property Name="GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
+ <Property Name="LAST_UPDATED" Type="DateTime" Nullable="false" Precision="3" />
+ <Property Name="CODE" Type="Int32" Nullable="false" />
+ <Property Name="NAME" Type="String" Nullable="false" MaxLength="100" FixedLength="false" Unicode="false" />
+ <Property Name="DESCRIPTION" Type="String" Nullable="false" MaxLength="100" FixedLength="false" Unicode="false" />
+ <Property Name="MIN" Type="Double" Nullable="false" />
+ <Property Name="MAX" Type="Double" Nullable="false" />
+ <Property Name="UNITS" Type="String" Nullable="false" MaxLength="50" FixedLength="false" Unicode="true" />
+ <Property Name="POINTS_PER_FRAME" Type="Int32" Nullable="false" />
+ <Property Name="MULTI_CHANNEL" Type="Boolean" Nullable="false" />
+ <Property Name="CHANNEL_COUNT" Type="Int32" Nullable="false" />
+ </EntityType>
<EntityType Name="HARDWARE_VERSIONS">
<Key>
<PropertyRef Name="GUID" />
@@ -2189,24 +2205,6 @@
<NavigationProperty Name="LIQUID_TYPES" Relationship="RemoteModel.FK_CONFIGURATIONS_DISPENSERS_LIQUIDS" FromRole="IDS_PACKS" ToRole="LIQUID_TYPES" />
<NavigationProperty Name="MID_TANK_TYPES" Relationship="RemoteModel.FK_IDS_PACKS_MID_TANK_TYPES" FromRole="IDS_PACKS" ToRole="MID_TANK_TYPES" />
</EntityType>
- <EntityType Name="IO">
- <Key>
- <PropertyRef Name="ID" />
- </Key>
- <Property Name="ID" Type="Int32" Nullable="false" annotation:StoreGeneratedPattern="Identity" />
- <Property Name="GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
- <Property Name="LAST_UPDATED" Type="DateTime" Nullable="false" Precision="3" />
- <Property Name="CODE" Type="Int32" Nullable="false" />
- <Property Name="TYPE" Type="Int32" Nullable="false" />
- <Property Name="NAME" Type="String" Nullable="false" MaxLength="100" FixedLength="false" Unicode="false" />
- <Property Name="DESCRIPTION" Type="String" Nullable="false" MaxLength="100" FixedLength="false" Unicode="false" />
- <Property Name="MIN" Type="Double" Nullable="false" />
- <Property Name="MAX" Type="Double" Nullable="false" />
- <Property Name="UNITS" Type="String" Nullable="false" MaxLength="50" FixedLength="false" Unicode="true" />
- <Property Name="POINTS_PER_FRAME" Type="Int32" Nullable="false" />
- <Property Name="MULTI_CHANNEL" Type="Boolean" Nullable="false" />
- <Property Name="CHANNEL_COUNT" Type="Int32" Nullable="false" />
- </EntityType>
<EntityType Name="JOB_RUNS">
<Key>
<PropertyRef Name="GUID" />
@@ -3551,6 +3549,24 @@
</MappingFragment>
</EntityTypeMapping>
</EntitySetMapping>
+ <EntitySetMapping Name="GRAPHS">
+ <EntityTypeMapping TypeName="RemoteModel.GRAPH">
+ <MappingFragment StoreEntitySet="GRAPHS">
+ <ScalarProperty Name="CHANNEL_COUNT" ColumnName="CHANNEL_COUNT" />
+ <ScalarProperty Name="MULTI_CHANNEL" ColumnName="MULTI_CHANNEL" />
+ <ScalarProperty Name="POINTS_PER_FRAME" ColumnName="POINTS_PER_FRAME" />
+ <ScalarProperty Name="UNITS" ColumnName="UNITS" />
+ <ScalarProperty Name="MAX" ColumnName="MAX" />
+ <ScalarProperty Name="MIN" ColumnName="MIN" />
+ <ScalarProperty Name="DESCRIPTION" ColumnName="DESCRIPTION" />
+ <ScalarProperty Name="NAME" ColumnName="NAME" />
+ <ScalarProperty Name="CODE" ColumnName="CODE" />
+ <ScalarProperty Name="LAST_UPDATED" ColumnName="LAST_UPDATED" />
+ <ScalarProperty Name="GUID" ColumnName="GUID" />
+ <ScalarProperty Name="ID" ColumnName="ID" />
+ </MappingFragment>
+ </EntityTypeMapping>
+ </EntitySetMapping>
<EntitySetMapping Name="HARDWARE_VERSIONS">
<EntityTypeMapping TypeName="RemoteModel.HARDWARE_VERSIONS">
<MappingFragment StoreEntitySet="HARDWARE_VERSIONS">
@@ -3592,25 +3608,6 @@
</MappingFragment>
</EntityTypeMapping>
</EntitySetMapping>
- <EntitySetMapping Name="IOS">
- <EntityTypeMapping TypeName="RemoteModel.IO">
- <MappingFragment StoreEntitySet="IOS">
- <ScalarProperty Name="CHANNEL_COUNT" ColumnName="CHANNEL_COUNT" />
- <ScalarProperty Name="MULTI_CHANNEL" ColumnName="MULTI_CHANNEL" />
- <ScalarProperty Name="POINTS_PER_FRAME" ColumnName="POINTS_PER_FRAME" />
- <ScalarProperty Name="UNITS" ColumnName="UNITS" />
- <ScalarProperty Name="MAX" ColumnName="MAX" />
- <ScalarProperty Name="MIN" ColumnName="MIN" />
- <ScalarProperty Name="DESCRIPTION" ColumnName="DESCRIPTION" />
- <ScalarProperty Name="NAME" ColumnName="NAME" />
- <ScalarProperty Name="TYPE" ColumnName="TYPE" />
- <ScalarProperty Name="CODE" ColumnName="CODE" />
- <ScalarProperty Name="LAST_UPDATED" ColumnName="LAST_UPDATED" />
- <ScalarProperty Name="GUID" ColumnName="GUID" />
- <ScalarProperty Name="ID" ColumnName="ID" />
- </MappingFragment>
- </EntityTypeMapping>
- </EntitySetMapping>
<EntitySetMapping Name="JOB_RUNS">
<EntityTypeMapping TypeName="RemoteModel.JOB_RUNS">
<MappingFragment StoreEntitySet="JOB_RUNS">
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
index e0dc9d5bf..59a914515 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
@@ -5,56 +5,56 @@
<!-- Diagram content (shape and connector positions) -->
<edmx:Diagrams>
<Diagram DiagramId="f9ae01d708754bbd997add25a4bacc79" Name="Diagram1">
- <EntityTypeShape EntityType="RemoteModel.ACTION_TYPES" Width="1.5" PointX="3" PointY="82.625" />
- <EntityTypeShape EntityType="RemoteModel.ADDRESS" Width="1.5" PointX="1.5" PointY="70.875" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_DISPLAY_PANEL_VERSIONS" Width="1.5" PointX="1.5" PointY="49.25" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_FIRMWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="55.125" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_OS_VERSIONS" Width="1.5" PointX="1.5" PointY="58" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_VERSIONS" Width="1.5" PointX="1.5" PointY="61" />
- <EntityTypeShape EntityType="RemoteModel.BRUSH_STOPS" Width="1.5" PointX="10.75" PointY="15.875" />
- <EntityTypeShape EntityType="RemoteModel.CARTRIDGE_TYPES" Width="1.5" PointX="9" PointY="35" />
- <EntityTypeShape EntityType="RemoteModel.CAT" Width="1.5" PointX="8.25" PointY="10.125" />
- <EntityTypeShape EntityType="RemoteModel.CCT" Width="1.5" PointX="5.25" PointY="17.625" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_SPACES" Width="1.5" PointX="8.5" PointY="21.875" />
- <EntityTypeShape EntityType="RemoteModel.CONFIGURATION" Width="1.5" PointX="0.75" PointY="40.5" />
- <EntityTypeShape EntityType="RemoteModel.CONTACT" Width="1.5" PointX="1.5" PointY="75.125" />
- <EntityTypeShape EntityType="RemoteModel.DISPENSER_TYPES" Width="1.5" PointX="9" PointY="41.375" />
- <EntityTypeShape EntityType="RemoteModel.EMBEDDED_FIRMWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="36.375" />
- <EntityTypeShape EntityType="RemoteModel.EMBEDDED_SOFTWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="33.375" />
- <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES" Width="1.5" PointX="3" PointY="64.5" />
- <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES_ACTIONS" Width="1.5" PointX="5.25" PointY="64.625" />
- <EntityTypeShape EntityType="RemoteModel.FIBER_SHAPES" Width="1.5" PointX="0.75" PointY="26.625" />
+ <EntityTypeShape EntityType="RemoteModel.ACTION_TYPES" Width="1.5" PointX="5.75" PointY="61.625" />
+ <EntityTypeShape EntityType="RemoteModel.ADDRESS" Width="1.5" PointX="1.5" PointY="48.75" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_DISPLAY_PANEL_VERSIONS" Width="1.5" PointX="1.5" PointY="56.25" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_FIRMWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="73" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_OS_VERSIONS" Width="1.5" PointX="1.5" PointY="53.375" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_VERSIONS" Width="1.5" PointX="1.5" PointY="67.125" />
+ <EntityTypeShape EntityType="RemoteModel.BRUSH_STOPS" Width="1.5" PointX="9.75" PointY="5.625" />
+ <EntityTypeShape EntityType="RemoteModel.CARTRIDGE_TYPES" Width="1.5" PointX="3" PointY="59.5" />
+ <EntityTypeShape EntityType="RemoteModel.CAT" Width="1.5" PointX="5.25" PointY="14.125" />
+ <EntityTypeShape EntityType="RemoteModel.CCT" Width="1.5" PointX="5.25" PointY="30.375" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_SPACES" Width="1.5" PointX="7.5" PointY="3.625" />
+ <EntityTypeShape EntityType="RemoteModel.CONFIGURATION" Width="1.5" PointX="0.75" PointY="60.5" />
+ <EntityTypeShape EntityType="RemoteModel.CONTACT" Width="1.5" PointX="1.5" PointY="36.625" />
+ <EntityTypeShape EntityType="RemoteModel.DISPENSER_TYPES" Width="1.5" PointX="3" PointY="62.375" />
+ <EntityTypeShape EntityType="RemoteModel.EMBEDDED_FIRMWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="78.875" />
+ <EntityTypeShape EntityType="RemoteModel.EMBEDDED_SOFTWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="70.125" />
+ <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES" Width="1.5" PointX="5.75" PointY="57.5" />
+ <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES_ACTIONS" Width="1.5" PointX="8" PointY="57.625" />
+ <EntityTypeShape EntityType="RemoteModel.FIBER_SHAPES" Width="1.5" PointX="0.75" PointY="18" />
<EntityTypeShape EntityType="RemoteModel.FIBER_SYNTHS" Width="1.5" PointX="0.75" PointY="20.875" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="52.125" />
- <EntityTypeShape EntityType="RemoteModel.IDS_PACK_FORMULAS" Width="1.5" PointX="9" PointY="25.125" />
- <EntityTypeShape EntityType="RemoteModel.IDS_PACKS" Width="1.5" PointX="11.25" PointY="23.875" />
- <EntityTypeShape EntityType="RemoteModel.IO" Width="1.5" PointX="0.75" PointY="0.75" />
- <EntityTypeShape EntityType="RemoteModel.JOB_RUNS" Width="1.5" PointX="7.5" PointY="6.375" />
- <EntityTypeShape EntityType="RemoteModel.JOB" Width="1.5" PointX="5.25" PointY="12.25" />
- <EntityTypeShape EntityType="RemoteModel.LINEAR_MASS_DENSITY_UNITS" Width="1.5" PointX="0.75" PointY="10" />
- <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES" Width="1.5" PointX="6" PointY="2" />
+ <EntityTypeShape EntityType="RemoteModel.GRAPH" Width="1.5" PointX="0.75" PointY="0.75" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_VERSIONS" Width="1.5" PointX="1.5" PointY="76" />
+ <EntityTypeShape EntityType="RemoteModel.IDS_PACK_FORMULAS" Width="1.5" PointX="3" PointY="82.75" />
+ <EntityTypeShape EntityType="RemoteModel.IDS_PACKS" Width="1.5" PointX="5.25" PointY="41.25" />
+ <EntityTypeShape EntityType="RemoteModel.JOB_RUNS" Width="1.5" PointX="7.5" PointY="17.875" />
+ <EntityTypeShape EntityType="RemoteModel.JOB" Width="1.5" PointX="5.25" PointY="8.25" />
+ <EntityTypeShape EntityType="RemoteModel.LINEAR_MASS_DENSITY_UNITS" Width="1.5" PointX="0.75" PointY="14.375" />
+ <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES" Width="1.5" PointX="3" PointY="21" />
<EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES_RMLS" Width="1.5" PointX="8.25" PointY="14.125" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE_VERSIONS" Width="1.5" PointX="0.75" PointY="30.125" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE" Width="1.5" PointX="3" PointY="43.875" />
- <EntityTypeShape EntityType="RemoteModel.MACHINES_CONFIGURATIONS" Width="1.5" PointX="5.25" PointY="43" />
- <EntityTypeShape EntityType="RemoteModel.MACHINES_EVENTS" Width="1.5" PointX="5.25" PointY="46.25" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_COLORS" Width="1.5" PointX="0.75" PointY="14.5" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_CONDITIONS" Width="1.5" PointX="0.75" PointY="17.875" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_MATERIALS" Width="1.5" PointX="0.75" PointY="7" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_PURPOSES" Width="1.5" PointX="0.75" PointY="23.75" />
- <EntityTypeShape EntityType="RemoteModel.MID_TANK_TYPES" Width="1.5" PointX="9" PointY="38" />
- <EntityTypeShape EntityType="RemoteModel.ORGANIZATION" Width="1.5" PointX="0.75" PointY="66.25" />
- <EntityTypeShape EntityType="RemoteModel.PERMISSION" Width="1.5" PointX="3.75" PointY="79.125" />
- <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES" Width="1.5" PointX="7.5" PointY="28.5" />
- <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES_GROUPS" Width="1.5" PointX="5.25" PointY="29.75" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE_VERSIONS" Width="1.5" PointX="0.75" PointY="41" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE" Width="1.5" PointX="3" PointY="43.375" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINES_CONFIGURATIONS" Width="1.5" PointX="5.25" PointY="53.5" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINES_EVENTS" Width="1.5" PointX="8" PointY="40.25" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_COLORS" Width="1.5" PointX="0.75" PointY="26.75" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_CONDITIONS" Width="1.5" PointX="0.75" PointY="7.125" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_MATERIALS" Width="1.5" PointX="0.75" PointY="23.875" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_PURPOSES" Width="1.5" PointX="0.75" PointY="10.125" />
+ <EntityTypeShape EntityType="RemoteModel.MID_TANK_TYPES" Width="1.5" PointX="3" PointY="86" />
+ <EntityTypeShape EntityType="RemoteModel.ORGANIZATION" Width="1.5" PointX="0.75" PointY="32" />
+ <EntityTypeShape EntityType="RemoteModel.PERMISSION" Width="1.5" PointX="3.75" PointY="66" />
+ <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES" Width="1.5" PointX="7.5" PointY="24.375" />
+ <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES_GROUPS" Width="1.5" PointX="5.25" PointY="25.625" />
<EntityTypeShape EntityType="RemoteModel.RML" Width="1.5" PointX="3" PointY="11.625" />
- <EntityTypeShape EntityType="RemoteModel.ROLE" Width="1.5" PointX="3.75" PointY="75" />
- <EntityTypeShape EntityType="RemoteModel.ROLES_PERMISSIONS" Width="1.5" PointX="6" PointY="75.125" />
- <EntityTypeShape EntityType="RemoteModel.SEGMENT" Width="1.5" PointX="7.5" PointY="17.75" />
+ <EntityTypeShape EntityType="RemoteModel.ROLE" Width="1.5" PointX="3.75" PointY="48.875" />
+ <EntityTypeShape EntityType="RemoteModel.ROLES_PERMISSIONS" Width="1.5" PointX="6" PointY="49" />
+ <EntityTypeShape EntityType="RemoteModel.SEGMENT" Width="1.5" PointX="7.5" PointY="7.375" />
<EntityTypeShape EntityType="RemoteModel.SYNC_CONFIGURATIONS" Width="1.5" PointX="2.75" PointY="0.75" />
- <EntityTypeShape EntityType="RemoteModel.USER" Width="1.5" PointX="3.75" PointY="70.5" />
- <EntityTypeShape EntityType="RemoteModel.USERS_ROLES" Width="1.5" PointX="6" PointY="71" />
- <EntityTypeShape EntityType="RemoteModel.WINDING_METHODS" Width="1.5" PointX="3" PointY="40.25" />
+ <EntityTypeShape EntityType="RemoteModel.USER" Width="1.5" PointX="3.75" PointY="36.25" />
+ <EntityTypeShape EntityType="RemoteModel.USERS_ROLES" Width="1.5" PointX="6" PointY="36.875" />
+ <EntityTypeShape EntityType="RemoteModel.WINDING_METHODS" Width="1.5" PointX="3" PointY="7.625" />
<AssociationConnector Association="RemoteModel.FK_EVENTS_ACTIONS_ACTIONS" />
<AssociationConnector Association="RemoteModel.FK_ORGANIZATIONS_ADDRESSES" />
<AssociationConnector Association="RemoteModel.FK_USERS_ADDRESSES" />
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/Tango.DAL.Remote.csproj b/Software/Visual_Studio/Tango.DAL.Remote/Tango.DAL.Remote.csproj
index 13a802eed..680716eb3 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/Tango.DAL.Remote.csproj
+++ b/Software/Visual_Studio/Tango.DAL.Remote/Tango.DAL.Remote.csproj
@@ -125,6 +125,9 @@
<Compile Include="DB\FIBER_SYNTHS.cs">
<DependentUpon>RemoteADO.tt</DependentUpon>
</Compile>
+ <Compile Include="DB\GRAPH.cs">
+ <DependentUpon>RemoteADO.tt</DependentUpon>
+ </Compile>
<Compile Include="DB\HARDWARE_VERSIONS.cs">
<DependentUpon>RemoteADO.tt</DependentUpon>
</Compile>
@@ -134,9 +137,6 @@
<Compile Include="DB\IDS_PACK_FORMULAS.cs">
<DependentUpon>RemoteADO.tt</DependentUpon>
</Compile>
- <Compile Include="DB\IO.cs">
- <DependentUpon>RemoteADO.tt</DependentUpon>
- </Compile>
<Compile Include="DB\JOB.cs">
<DependentUpon>RemoteADO.tt</DependentUpon>
</Compile>
diff --git a/Software/Visual_Studio/Tango.Integration/Observables/Enumerations/Graphs.cs b/Software/Visual_Studio/Tango.Integration/Observables/Enumerations/Graphs.cs
new file mode 100644
index 000000000..798844351
--- /dev/null
+++ b/Software/Visual_Studio/Tango.Integration/Observables/Enumerations/Graphs.cs
@@ -0,0 +1,181 @@
+using System;
+using System.Collections.Generic;
+using System.Collections.ObjectModel;
+using System.Linq;
+using System.ComponentModel;
+
+namespace Tango.Integration.Observables
+{
+ public enum Graphs
+ {
+
+ /// <summary>
+ /// (Dancer 1)
+ /// </summary>
+ [Description("Dancer 1")]
+ Dancer1Angle = 0,
+
+ /// <summary>
+ /// (Dancer 2)
+ /// </summary>
+ [Description("Dancer 2")]
+ Dancer2Angle = 1,
+
+ /// <summary>
+ /// (Dancer 3)
+ /// </summary>
+ [Description("Dancer 3")]
+ Dancer3Angle = 2,
+
+ /// <summary>
+ /// (Feeder Motor)
+ /// </summary>
+ [Description("Feeder Motor")]
+ FeederMotorFrequency = 3,
+
+ /// <summary>
+ /// (Dryer Motor)
+ /// </summary>
+ [Description("Dryer Motor")]
+ DryerMotor = 4,
+
+ /// <summary>
+ /// (Poller Motor)
+ /// </summary>
+ [Description("Poller Motor")]
+ PollerMotor = 5,
+
+ /// <summary>
+ /// (Winder Motor)
+ /// </summary>
+ [Description("Winder Motor")]
+ WinderMotor = 6,
+
+ /// <summary>
+ /// (Screw Motor)
+ /// </summary>
+ [Description("Screw Motor")]
+ ScrewMotor = 7,
+
+ /// <summary>
+ /// (Thread Speed)
+ /// </summary>
+ [Description("Thread Speed")]
+ ThreadSpeed = 8,
+
+ /// <summary>
+ /// (Mixer)
+ /// </summary>
+ [Description("Mixer")]
+ MixerTemperature = 9,
+
+ /// <summary>
+ /// (Head Zone 1)
+ /// </summary>
+ [Description("Head Zone 1")]
+ HeadZone1Temperature = 10,
+
+ /// <summary>
+ /// (Head Zone 2)
+ /// </summary>
+ [Description("Head Zone 2")]
+ HeadZone2Temperature = 11,
+
+ /// <summary>
+ /// (Head Zone 3)
+ /// </summary>
+ [Description("Head Zone 3")]
+ HeadZone3Temperature = 12,
+
+ /// <summary>
+ /// (Head Air Flow)
+ /// </summary>
+ [Description("Head Air Flow")]
+ HeadAirFlow = 13,
+
+ /// <summary>
+ /// (Feeder Tension)
+ /// </summary>
+ [Description("Feeder Tension")]
+ FeederTension = 14,
+
+ /// <summary>
+ /// (Puller Tension)
+ /// </summary>
+ [Description("Puller Tension")]
+ PullerTension = 15,
+
+ /// <summary>
+ /// (Dryer Zone 1)
+ /// </summary>
+ [Description("Dryer Zone 1")]
+ DryerZone1Temperature = 16,
+
+ /// <summary>
+ /// (Dryer Zone 2)
+ /// </summary>
+ [Description("Dryer Zone 2")]
+ DryerZone2Temperature = 17,
+
+ /// <summary>
+ /// (Dryer Zone 3)
+ /// </summary>
+ [Description("Dryer Zone 3")]
+ DryerZone3Temperature = 18,
+
+ /// <summary>
+ /// (Dryer Air Flow)
+ /// </summary>
+ [Description("Dryer Air Flow")]
+ DryerAirFlow = 19,
+
+ /// <summary>
+ /// (Winder Tension)
+ /// </summary>
+ [Description("Winder Tension")]
+ WinderTension = 20,
+
+ /// <summary>
+ /// (Dispensers Motors)
+ /// </summary>
+ [Description("Dispensers Motors")]
+ DispensersMotorsFrequency = 21,
+
+ /// <summary>
+ /// (Dispensers Angular Encoders)
+ /// </summary>
+ [Description("Dispensers Angular Encoders")]
+ DispensersAngularEncoders = 22,
+
+ /// <summary>
+ /// (Dispensers Linear Positions)
+ /// </summary>
+ [Description("Dispensers Linear Positions")]
+ DispensersLinearPositions = 23,
+
+ /// <summary>
+ /// (Dispensers Pressure)
+ /// </summary>
+ [Description("Dispensers Pressure")]
+ DispensersPressure = 24,
+
+ /// <summary>
+ /// (Mid Tank Pressure)
+ /// </summary>
+ [Description("Mid Tank Pressure")]
+ MidTankPressure = 25,
+
+ /// <summary>
+ /// (Filter Delta Pressure)
+ /// </summary>
+ [Description("Filter Delta Pressure")]
+ FilterDeltaPressure = 26,
+
+ /// <summary>
+ /// (Chiller Temperature)
+ /// </summary>
+ [Description("Chiller Temperature")]
+ ChillerTemperature = 27,
+
+ }
+}
diff --git a/Software/Visual_Studio/Tango.Integration/Observables/Enumerations/IOType.cs b/Software/Visual_Studio/Tango.Integration/Observables/Enumerations/IOType.cs
deleted file mode 100644
index 5a6166295..000000000
--- a/Software/Visual_Studio/Tango.Integration/Observables/Enumerations/IOType.cs
+++ /dev/null
@@ -1,17 +0,0 @@
-using System;
-using System.Collections.Generic;
-using System.Linq;
-using System.Text;
-using System.Threading.Tasks;
-
-namespace Tango.Integration.Observables.Enumerations
-{
- public enum IOType
- {
- Undefined = 0,
- Input = 1,
- Output = 2,
- InputOutput = 3,
- Switch = 4,
- }
-}
diff --git a/Software/Visual_Studio/Tango.Integration/Observables/ObservablesContext.cs b/Software/Visual_Studio/Tango.Integration/Observables/ObservablesContext.cs
index dde8c7c22..9e6037998 100644
--- a/Software/Visual_Studio/Tango.Integration/Observables/ObservablesContext.cs
+++ b/Software/Visual_Studio/Tango.Integration/Observables/ObservablesContext.cs
@@ -208,33 +208,33 @@ namespace Tango.Integration.Observables
}
/// <summary>
- /// Gets or sets the HardwareVersions.
+ /// Gets or sets the Graphs.
/// </summary>
- public DbSet<HardwareVersion> HardwareVersions
+ public DbSet<Graph> Graphs
{
get; set;
}
/// <summary>
- /// Gets or sets the IdsPackFormulas.
+ /// Gets or sets the HardwareVersions.
/// </summary>
- public DbSet<IdsPackFormula> IdsPackFormulas
+ public DbSet<HardwareVersion> HardwareVersions
{
get; set;
}
/// <summary>
- /// Gets or sets the IdsPacks.
+ /// Gets or sets the IdsPackFormulas.
/// </summary>
- public DbSet<IdsPack> IdsPacks
+ public DbSet<IdsPackFormula> IdsPackFormulas
{
get; set;
}
/// <summary>
- /// Gets or sets the Ios.
+ /// Gets or sets the IdsPacks.
/// </summary>
- public DbSet<Io> Ios
+ public DbSet<IdsPack> IdsPacks
{
get; set;
}
diff --git a/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapter.cs b/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapter.cs
index 8c080ad7a..a347285cc 100644
--- a/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapter.cs
+++ b/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapter.cs
@@ -259,7 +259,7 @@ namespace Tango.Integration.Observables
WindingMethods = Context.WindingMethods.ToObservableCollection();
- Ios = Context.Ios.ToObservableCollection();
+ Graphs = Context.Graphs.ToObservableCollection();
IdsPackFormulas = Context.IdsPackFormulas.ToObservableCollection();
diff --git a/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapterExtension.cs b/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapterExtension.cs
index 636b0d8cb..4f47fe051 100644
--- a/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapterExtension.cs
+++ b/Software/Visual_Studio/Tango.Integration/Observables/ObservablesEntitiesAdapterExtension.cs
@@ -726,6 +726,42 @@ namespace Tango.Integration.Observables
}
+ private ObservableCollection<Graph> _graphs;
+ /// <summary>
+ /// Gets or sets the Graphs.
+ /// </summary>
+ public ObservableCollection<Graph> Graphs
+ {
+ get
+ {
+ return _graphs;
+ }
+
+ set
+ {
+ _graphs = value; RaisePropertyChanged(nameof(Graphs));
+ }
+
+ }
+
+ private ICollectionView _graphsViewSource;
+ /// <summary>
+ /// Gets or sets the Graphs View Source.
+ ///</summary>
+ public ICollectionView GraphsViewSource
+ {
+ get
+ {
+ return _graphsViewSource;
+ }
+
+ set
+ {
+ _graphsViewSource = value; RaisePropertyChanged(nameof(GraphsViewSource));
+ }
+
+ }
+
private ObservableCollection<HardwareVersion> _hardwareversions;
/// <summary>
/// Gets or sets the HardwareVersions.
@@ -834,42 +870,6 @@ namespace Tango.Integration.Observables
}
- private ObservableCollection<Io> _ios;
- /// <summary>
- /// Gets or sets the Ios.
- /// </summary>
- public ObservableCollection<Io> Ios
- {
- get
- {
- return _ios;
- }
-
- set
- {
- _ios = value; RaisePropertyChanged(nameof(Ios));
- }
-
- }
-
- private ICollectionView _iosViewSource;
- /// <summary>
- /// Gets or sets the Ios View Source.
- ///</summary>
- public ICollectionView IosViewSource
- {
- get
- {
- return _iosViewSource;
- }
-
- set
- {
- _iosViewSource = value; RaisePropertyChanged(nameof(IosViewSource));
- }
-
- }
-
private ObservableCollection<JobRun> _jobruns;
/// <summary>
/// Gets or sets the JobRuns.
@@ -1852,14 +1852,14 @@ namespace Tango.Integration.Observables
FiberSynthsViewSource = CreateCollectionView(FiberSynths);
+ GraphsViewSource = CreateCollectionView(Graphs);
+
HardwareVersionsViewSource = CreateCollectionView(HardwareVersions);
IdsPackFormulasViewSource = CreateCollectionView(IdsPackFormulas);
IdsPacksViewSource = CreateCollectionView(IdsPacks);
- IosViewSource = CreateCollectionView(Ios);
-
JobRunsViewSource = CreateCollectionView(JobRuns);
JobsViewSource = CreateCollectionView(Jobs);
diff --git a/Software/Visual_Studio/Tango.Integration/Tango.Integration.csproj b/Software/Visual_Studio/Tango.Integration/Tango.Integration.csproj
index 5e30f6ccf..68c1ccff6 100644
--- a/Software/Visual_Studio/Tango.Integration/Tango.Integration.csproj
+++ b/Software/Visual_Studio/Tango.Integration/Tango.Integration.csproj
@@ -109,7 +109,7 @@
<Compile Include="Observables\Entities\HardwareVersion.cs" />
<Compile Include="Observables\Entities\IdsPack.cs" />
<Compile Include="Observables\Entities\IdsPackFormula.cs" />
- <Compile Include="Observables\Entities\Io.cs" />
+ <Compile Include="Observables\Entities\Graph.cs" />
<Compile Include="Observables\Entities\Job.cs" />
<Compile Include="Observables\Entities\JobRun.cs" />
<Compile Include="Observables\Entities\LinearMassDensityUnit.cs" />
@@ -145,7 +145,6 @@
<Compile Include="Observables\Enumerations\FiberShapes.cs" />
<Compile Include="Observables\Enumerations\FiberSynthesises.cs" />
<Compile Include="Observables\Enumerations\IdsPackFormulas.cs" />
- <Compile Include="Observables\Enumerations\IOType.cs" />
<Compile Include="Observables\Enumerations\LinearMassDensityUnits.cs" />
<Compile Include="Observables\Enumerations\Liquids.cs" />
<Compile Include="Observables\Enumerations\MediaConditions.cs" />
diff --git a/Software/Visual_Studio/Tango.Integration/Observables/Entities/Io.cs b/Software/Visual_Studio/Tango.Integration/Observables/Entities/Graph.cs
index e0fefc8b0..3bb7c26c8 100644
--- a/Software/Visual_Studio/Tango.Integration/Observables/Entities/Io.cs
+++ b/Software/Visual_Studio/Tango.Integration/Observables/Entities/Graph.cs
@@ -8,13 +8,13 @@ using Tango.DAL.Remote.DB;
namespace Tango.Integration.Observables
{
- [Table("IOS")]
- public partial class Io : ObservableEntity<Io>
+ [Table("GRAPHS")]
+ public partial class Graph : ObservableEntity<Graph>
{
protected Int32 _code;
/// <summary>
/// Gets or sets the io code.
/// </summary>
[Column("CODE")]
@@ -32,29 +32,9 @@ namespace Tango.Integration.Observables
}
- protected Int32 _type;
- /// <summary>
- /// Gets or sets the io type.
- /// </summary>
- [Column("TYPE")]
-
- public Int32 Type
- {
- get
- {
- return _type;
- }
-
- set
- {
- _type = value; RaisePropertyChanged(nameof(Type));
- }
-
- }
-
protected String _name;
/// <summary>
/// Gets or sets the io name.
/// </summary>
[Column("NAME")]
@@ -74,7 +54,7 @@ namespace Tango.Integration.Observables
protected String _description;
/// <summary>
/// Gets or sets the io description.
/// </summary>
[Column("DESCRIPTION")]
@@ -94,7 +74,7 @@ namespace Tango.Integration.Observables
protected Double _min;
/// <summary>
/// Gets or sets the io min.
/// </summary>
[Column("MIN")]
@@ -114,7 +94,7 @@ namespace Tango.Integration.Observables
protected Double _max;
/// <summary>
/// Gets or sets the io max.
/// </summary>
[Column("MAX")]
@@ -134,7 +114,7 @@ namespace Tango.Integration.Observables
protected String _units;
/// <summary>
/// Gets or sets the io units.
/// </summary>
[Column("UNITS")]
@@ -154,7 +134,7 @@ namespace Tango.Integration.Observables
protected Int32 _pointsperframe;
/// <summary>
/// Gets or sets the io points per frame.
/// </summary>
[Column("POINTS_PER_FRAME")]
@@ -174,7 +154,7 @@ namespace Tango.Integration.Observables
protected Boolean _multichannel;
/// <summary>
/// Gets or sets the io multi channel.
/// </summary>
[Column("MULTI_CHANNEL")]
@@ -194,7 +174,7 @@ namespace Tango.Integration.Observables
protected Int32 _channelcount;
/// <summary>
/// Gets or sets the io channel count.
/// </summary>
[Column("CHANNEL_COUNT")]
@@ -213,9 +193,9 @@ namespace Tango.Integration.Observables
}
/// <summary>
/// Initializes a new instance of the <see cref="Io" /> class.
/// </summary>
- public Io() : base()
+ public Graph() : base()
{
}
}
@@ -8,13 +8,13 @@ using Tango.DAL.Remote.DB;
protected Int32 _code;
/// <summary>
- /// Gets or sets the io code.
+ /// Gets or sets the graph code.
/// </summary>
[Column("CODE")]
@@ -32,29 +32,9 @@ namespace Tango.Integration.Observables
protected String _name;
/// <summary>
- /// Gets or sets the io name.
+ /// Gets or sets the graph name.
/// </summary>
[Column("NAME")]
@@ -74,7 +54,7 @@ namespace Tango.Integration.Observables
protected String _description;
/// <summary>
- /// Gets or sets the io description.
+ /// Gets or sets the graph description.
/// </summary>
[Column("DESCRIPTION")]
@@ -94,7 +74,7 @@ namespace Tango.Integration.Observables
protected Double _min;
/// <summary>
- /// Gets or sets the io min.
+ /// Gets or sets the graph min.
/// </summary>
[Column("MIN")]
@@ -114,7 +94,7 @@ namespace Tango.Integration.Observables
protected Double _max;
/// <summary>
- /// Gets or sets the io max.
+ /// Gets or sets the graph max.
/// </summary>
[Column("MAX")]
@@ -134,7 +114,7 @@ namespace Tango.Integration.Observables
protected String _units;
/// <summary>
- /// Gets or sets the io units.
+ /// Gets or sets the graph units.
/// </summary>
[Column("UNITS")]
@@ -154,7 +134,7 @@ namespace Tango.Integration.Observables
protected Int32 _pointsperframe;
/// <summary>
- /// Gets or sets the io points per frame.
+ /// Gets or sets the graph points per frame.
/// </summary>
[Column("POINTS_PER_FRAME")]
@@ -174,7 +154,7 @@ namespace Tango.Integration.Observables
protected Boolean _multichannel;
/// <summary>
- /// Gets or sets the io multi channel.
+ /// Gets or sets the graph multi channel.
/// </summary>
[Column("MULTI_CHANNEL")]
@@ -194,7 +174,7 @@ namespace Tango.Integration.Observables
protected Int32 _channelcount;
/// <summary>
- /// Gets or sets the io channel count.
+ /// Gets or sets the graph channel count.
/// </summary>
[Column("CHANNEL_COUNT")]
@@ -213,9 +193,9 @@ namespace Tango.Integration.Observables
}
/// <summary>
- /// Initializes a new instance of the <see cref="Io" /> class.
+ /// Initializes a new instance of the <see cref="Graph" /> class.
/// </summary>